/// <reference types="node" />
import { EventEmitter } from "events";
import { ByteArray, Connection, ValueOf } from "../utils";
import { Player, Room } from "../structures";
import { languages } from "../enums";
import ClientEvents from "./Events";
/**
 * Client interface for event intellisense support
 */
declare interface Client {
    on<T extends keyof ClientEvents>(event: T, listener: ClientEvents[T]): this;
    emit<T extends keyof ClientEvents>(event: T, ...args: Parameters<ClientEvents[T]>): boolean;
}
/** Represents a client that connects to Transformice. */
declare class Client extends EventEmitter {
    private loops;
    private version;
    private connectionKey;
    private authClient;
    private authServer;
    private ports;
    private host;
    private tribulleID;
    identificationKeys: number[];
    msgKeys: number[];
    /**
     * The online players when the bot log.
     */
    onlinePlayers: number;
    /**
     * The client's room.
     */
    room: Room;
    /**
     * The client's player.
     */
    player: Player;
    /**
     * The client's ID.
     */
    playerID: number;
    /**
     * The client's nickname.
     */
    nickname: string;
    /**
     * The client's playing time.
     */
    playingTime: number;
    /**
     * The connection time.
     */
    connectionTime: number;
    /**
     * The client's community code.
     */
    community: number;
    /**
     * The language suggested by the server.
     */
    language: string;
    /**
     * The client's temporary code.
     */
    pcode: number;
    main: Connection;
    bulle: Connection;
    constructor();
    /**
     * Handles the old packets and emits events.
     */
    private handleOldPacket;
    /**
     * Handles the known packets and emits events.
     */
    handlePacket(conn: Connection, packet: ByteArray): void;
    /**
     * Handles the community platform packets and emits events.
     */
    private handleTribulle;
    /**
     * Sends a packet to the community platform (tribulle).
     */
    private sendTribullePacket;
    /**
     * Log in to the game.
     */
    login(nickname: string, password: string, room?: string): void;
    /**
     * Sends Handshake.
     */
    private sendHandshake;
    /**
     * Sets the language of the client.
     * @param {enums.language} [id=enums.language.en] - The language iso code.
     */
    private setLanguage;
    private setSystemInfo;
    /**
     * Joins the tribe house.
     */
    joinTribeHouse(): void;
    /**
     * Load a lua script in the room.
     */
    loadLua(script: string): void;
    /**
     * Sends a message to the client's room.
     * @param {String} message - The message.
     */
    sendRoomMessage(message: string): void;
    /**
     * Sends a server command.
     * @param message - The command message (without the `/`).
     * @example
     * client.sendCommand('mod');
     */
    sendCommand(message: string): void;
    /**
     * Sends a request to the server to join a room with specific name.
     */
    joinRoom(name: string, isSalonAuto?: boolean): void;
    /**
     * Sends a whisper message to a player.
     */
    sendWhisper(nickname: string, message: string): void;
    /**
     * Request friend list.
     */
    requestFriendList(): void;
    /**
     * Sends a packet every 15 seconds to stay connected to the game.
     */
    startHeartbeat(): void;
    /**
     * Starts the client.
     */
    run(tfmid: string, token: string, nickname: string, password: string, language?: ValueOf<typeof languages>, room?: string): Promise<void>;
    /**
     * Disconnects the client.
     */
    disconnect(): void;
}
export default Client;
